package it.polito.bigdata.hadoop;

import java.io.IOException;

import com.amazonaws.services.dynamodbv2.xspec.NULL;
import org.apache.hadoop.io.DoubleWritable;
import org.apache.hadoop.io.IntWritable;
import org.apache.hadoop.io.NullWritable;
import org.apache.hadoop.io.Text;
import org.apache.hadoop.mapreduce.Mapper;
import org.apache.hadoop.mapreduce.Reducer;

/**
 * Basic MapReduce Project - Reducer
 */
class ReducerBigData extends Reducer<
                Text,
                IntWritable,
                Text,
                DoubleWritable> {
    private double avgMax;
    private String orgCIDMax;

    @Override
    protected void setup(Context context) throws IOException, InterruptedException {
        avgMax = -1;
        orgCIDMax = "";
    }

    @Override
    protected void reduce(
        Text key,
        Iterable<IntWritable> values,
        Context context) throws IOException, InterruptedException {
        int count = 0;
        String cid = key.toString();
        int sum = 0;

        for(IntWritable v : values) {
            count++;
            sum += v.get();
        }

        double avg = (double) sum / count;
        if(avg > avgMax || (avg == avgMax && cid.compareTo(orgCIDMax) < 0)) {
            avgMax = avg;
            orgCIDMax = cid;
        }

    }

    @Override
    protected void cleanup(Context context) throws IOException, InterruptedException {
        context.write(new Text(orgCIDMax), new DoubleWritable(avgMax));
    }
}
